@@ -4,8 +4,9 @@ import os
 from google.cloud import firestore
 from bs4 import BeautifulSoup
 import requests
-from .decorators import func_exec_time
 from datetime import datetime
+import base64
+
 
 JOB_STATES = ["queued", "completed", "skipped", "error"]
 ENV_VAR_MSG = "Specified environment variable is not set."
@@ -310,19 +311,11 @@ class AniRotationEngine(AbstractService):
             self.config['params']['user'],
             self.config['params']['password']
         )
-        profile_obj = app_instance.get_campaign_profile(
-            config['configuration']['profiles'][0])
-        profile_config = {
-            "ANI": config['configuration']['aniPool'][0]['ani'],
-            "description": profile_obj['description'],
-            "dialingSchedule": profile_obj['dialingSchedule'],
-            "dialingTimeout": profile_obj['dialingTimeout'],
-            "initialCallPriority": profile_obj['initialCallPriority'],
-            "maxCharges": profile_obj['maxCharges'],
-            "name": profile_obj['name'],
-            "numberOfAttempts": profile_obj['numberOfAttempts'],
-        }
-        app_instance.update_campaign_profile(profile_config)
+        self.rotate_ani(
+            config['configuration']['aniPool'],
+            config['configuration']['profiles'][0],
+            app_instance,
+            True)
         old_ani = config['configuration']['aniPool'][1]['ani'] if len(
             config['configuration']['aniPool']) > 1 else 'ANI deleted from pool.'
         return self.notify_change(config['configuration']['aniPool'][0]['ani'], old_ani, ROT_TYPES[2], config['configuration']['notifications']['to'], config['configuration']['notifications']['cc'], config['configuration']['profiles'][0])
@@ -416,12 +409,12 @@ class AniRotationEngine(AbstractService):
         answer = "404" not in text
         return answer
 
-    def rotate_ani(self, ani_pool: list, profile, client):
-        profile = client.get_campaign_profile(profile)
+    def rotate_ani(self, ani_pool: list, profile_name, client, on_demand=False):
+        profile = client.get_campaign_profile(profile_name)
         inbound_campaigns = [
-            c['name'] for c in client.get_inbound_campaigns() if c['profileName'] == profile]
+            c['name'] for c in client.get_inbound_campaigns() if c['profileName'] == profile['name']]
         profile_config = {
-            "ANI": ani_pool[1]['ani'],
+            "ANI": ani_pool[1]['ani'] if not on_demand else ani_pool[0]['ani'],
             "description": profile['description'],
             "dialingSchedule": profile['dialingSchedule'],
             "dialingTimeout": profile['dialingTimeout'],
@@ -432,11 +425,15 @@ class AniRotationEngine(AbstractService):
         }
         client.update_campaign_profile(profile_config)
         for campaign in inbound_campaigns:
-            client.update_dnis_list(campaign, [ani_pool[1]['ani']])
-        deactivated_ani = ani_pool.pop(0)
-        deactivated_ani['active'] = False
-        ani_pool.append(deactivated_ani)
-        ani_pool[0]['active'] = True
+            client.remove_dnis_list(
+                campaign, [ani_pool[0]['ani']] if not on_demand else [ani_pool[-1]['ani']])
+            client.update_dnis_list(
+                campaign, [ani_pool[1]['ani']] if not on_demand else [ani_pool[0]['ani']])
+        if not on_demand:
+            deactivated_ani = ani_pool.pop(0)
+            deactivated_ani['active'] = False
+            ani_pool.append(deactivated_ani)
+            ani_pool[0]['active'] = True
         return ani_pool
 
     def send_new_request(self, config, reason):
@@ -499,7 +496,10 @@ class AniRotationEngine(AbstractService):
         password = os.environ.get('PASSWORD', ENV_VAR_MSG)
         recipients = config['configuration']['requestSchedule']['recipients'].split(
         ) + config['configuration']['requestSchedule']['cc'].split()
-        subject = "New DID request"
+        request_id = base64.b64encode(
+            config['configuration']['profiles'][0].encode("utf-8"))
+        encoded_id = str(request_id, "utf-8")
+        subject = f"New DID request - Request ID {encoded_id}"
         body = f"""
         Hi {config['configuration']['requestSchedule']['recipients'].split(".")[0]} <br><br>
         Can we please order {amount} new number{"s" if amount > 1 else ""} for {"any of the" if len(config['configuration']['requestSchedule']['areaCodes'].split(",")) > 1 else "the"} area code{"s" if len(config['configuration']['requestSchedule']['areaCodes'].split(",")) > 1 else ""}
@@ -640,7 +640,7 @@ class Five9ToGHL(AbstractService):
             self.config['params']['user'],
             self.config['params']['password']
         )
-        if "Inbound" not in self.data['type_name']:
+        if "Inbound" not in self.data['campaign_name']:
             location_id = five9_client.get_outbound_campaigns(
                 self.data['campaign_name'])[0]['description'].strip()
         if "Inbound" in self.data['campaign_name']:
